pub struct WpanFacade { /* private fields */ }Expand description
Perform Wpan FIDL operations.
Note this object is shared among all threads created by server.
Implementations
Sourceimpl WpanFacade
impl WpanFacade
pub fn new() -> WpanFacade
Sourcepub async fn initialize_proxies(&self) -> Result<(), Error>
pub async fn initialize_proxies(&self) -> Result<(), Error>
Returns the DeviceTestManager proxy provided on instantiation or establishes a new connection.
Sourcepub async fn get_thread_rloc16(&self) -> Result<u16, Error>
pub async fn get_thread_rloc16(&self) -> Result<u16, Error>
Returns the thread rloc from the DeviceTest proxy service.
Sourcepub async fn get_ncp_mac_address(&self) -> Result<[u8; 8], Error>
pub async fn get_ncp_mac_address(&self) -> Result<[u8; 8], Error>
Returns the current mac address (thread random mac address) from the DeviceTest proxy service.
Sourcepub async fn get_ncp_channel(&self) -> Result<u16, Error>
pub async fn get_ncp_channel(&self) -> Result<u16, Error>
Returns the ncp channel from the DeviceTest proxy service.
Sourcepub async fn get_ncp_rssi(&self) -> Result<i32, Error>
pub async fn get_ncp_rssi(&self) -> Result<i32, Error>
Returns the current rssi from the DeviceTest proxy service.
Sourcepub async fn get_weave_node_id(&self) -> Result<[u8; 8], Error>
pub async fn get_weave_node_id(&self) -> Result<[u8; 8], Error>
Returns the factory mac address from the DeviceTest proxy service.
Sourcepub async fn get_network_name(&self) -> Result<Vec<u8>, Error>
pub async fn get_network_name(&self) -> Result<Vec<u8>, Error>
Returns the network name from the DeviceExtra proxy service.
Sourcepub async fn get_partition_id(&self) -> Result<u32, Error>
pub async fn get_partition_id(&self) -> Result<u32, Error>
Returns the partition id from the DeviceTest proxy service.
Sourcepub async fn get_thread_router_id(&self) -> Result<u8, Error>
pub async fn get_thread_router_id(&self) -> Result<u8, Error>
Returns the thread router id from the DeviceTest proxy service.
Sourcepub async fn get_ncp_device_state(&self) -> Result<DeviceStateDto, Error>
pub async fn get_ncp_device_state(&self) -> Result<DeviceStateDto, Error>
Returns the device state from the DeviceTest proxy service.
Sourcepub async fn get_ncp_state(&self) -> Result<ConnectivityState, Error>
pub async fn get_ncp_state(&self) -> Result<ConnectivityState, Error>
Returns the connectivity state from the DeviceTest proxy service.
Sourcepub async fn get_is_commissioned(&self) -> Result<bool, Error>
pub async fn get_is_commissioned(&self) -> Result<bool, Error>
Returns true if the connectivity state is commissioned.
Sourcepub async fn get_panid(&self) -> Result<u16, Error>
pub async fn get_panid(&self) -> Result<u16, Error>
Returns the panid from the DeviceExtra proxy service.
Sourcepub async fn get_mac_address_filter_settings(
&self,
) -> Result<MacAddressFilterSettingsDto, Error>
pub async fn get_mac_address_filter_settings( &self, ) -> Result<MacAddressFilterSettingsDto, Error>
Returns the mac address filter settings from the DeviceTest proxy service.
Sourcepub async fn replace_mac_address_filter_settings(
&self,
settings: MacAddressFilterSettingsDto,
) -> Result<(), Error>
pub async fn replace_mac_address_filter_settings( &self, settings: MacAddressFilterSettingsDto, ) -> Result<(), Error>
Replaces the mac address filter settings on the DeviceTest proxy service.
Sourcepub async fn get_neighbor_table(&self) -> Result<Vec<NeighborInfoDto>, Error>
pub async fn get_neighbor_table(&self) -> Result<Vec<NeighborInfoDto>, Error>
Returns the thread neighbor table from the DeviceTest proxy service.